==> wlp-webProfile7-22.0.0.12.zip: OSGI-INF/welcome/nls/de/messages.js <==
var messages = {
    WELCOME: "Willkommen bei Liberty",
    WEBSPHERE_LIBERTY_LOGO: "WebSphere Liberty-Logo",
    OPEN_LIBERTY_LOGO: "Open Liberty-Logo",
    WELCOME_SECTION: "Willkommensbereich",
    WELCOME_SECTION_CONTENT: "Inhalt des Willkommensbereichs",
    WEBSPHERE_APPSERVER: "WebSphere Application Server Beta",
    HOW_TO_SETUP_ADMIN_CENTER: "Vorgehensweise beim Einrichten des Admin Center",
    OPEN_ADMIN_CENTER: "Admin Center öffnen",
    ADDITIONAL_RESOURCES: "Weitere Ressourcen",
    EXTERNAL_RESOURCES: "Externe Ressourcen",
    OPEN_LIBERT_SUPPORT: "Open Liberty-Community",
    WEBSPHERE_LIBERTY_DOC: "WebSphere Liberty-Dokumentation",
    APPLICABLE_CONTENT: "Alle Open Liberty-Inhalte sind auf WebSphere Liberty anwendbar: ",
    OPEN_LIBERTY_DOC: "Open Liberty-Dokumentation",
    OPEN_LIBERTY_GUIDES: "Open Liberty-Handbücher",
    WEBSPHERE_LIBERTY_FORUM: "WebSphere Liberty-Forum",
    HEADER_UPDATE_AVAILABLE: "Aktualisierung verfügbar: ",
    HEADER_DOWNLOAD_LINK: "Klicken Sie zum Herunterladen auf {0}", // Product name
    HEADER_UPDATE_AVAILABLE_DOWNLOAD_LINK: "Es ist eine Aktualisierung verfügbar. Klicken Sie zum Herunterladen auf {0}", // Product name
    COPYRIGHT: "Copyright",
    IBM_LOGO: "IBM Logo",
    IBM_LICENSED: "Licensed Materials — Property of IBM © Copyright IBM Corp. 1997, 2019. All Rights Reserved. IBM und das IBM Logo sind Marken oder eingetragene Marken der International Business Machines Corporation in den USA und/oder anderen Ländern. Weitere Produkt- und Servicenamen können Marken von IBM oder anderen Unternehmen sein. Eine aktuelle Liste der IBM Marken finden Sie im Web unter {0}", // COPYRIGHT_URL
    COPYRIGHT_URL: "'Copyright and trademark information'.",
    CONTEXT_ROOT_NOT_FOUND: "Kontextstammverzeichnis nicht gefunden.",
    UPDATE_BANNER_CLOSE_BUTTON: "Banner schließen",
    UPDATE_BANNER_SECTION: "Bannerbereich aktualisieren",
    UPDATE_BANNER_SECTION_CONTENT: "Inhalt des Bannerbereichs aktualisieren",
    BUILT_ON: "Erstellt unter ",
    LINKS: "Links: "
};

==> wlp-webProfile8-20.0.0.8.zip: OSGI-INF/welcome/nls/de/messages.js <==
var messages = {
    WELCOME: "Willkommen bei Liberty",
    WEBSPHERE_LIBERTY_LOGO: "WebSphere Liberty-Logo",
    WELCOME_SECTION: "Willkommensbereich",
    WELCOME_SECTION_CONTENT: "Inhalt des Willkommensbereichs",
    WEBSPHERE_APPSERVER: "WebSphere Application Server Beta",
    HOW_TO_SETUP_ADMIN_CENTER: "Vorgehensweise beim Einrichten des Admin Center",
    OPEN_ADMIN_CENTER: "Admin Center öffnen",
    ADDITIONAL_RESOURCES: "Weitere Ressourcen",
    EXTERNAL_RESOURCES: "Externe Ressourcen",
    WASDEV: "WASdev-Community",
    LIBERTY_DOC: "Liberty-Dokumentation",
    WASDEV_FORUM: "WASdev-Forum",
    HEADER_UPDATE_AVAILABLE: "Aktualisierung verfügbar: ",
    HEADER_DOWNLOAD_LINK: "Klicken Sie zum Herunterladen auf {0}", // Product name
    HEADER_UPDATE_AVAILABLE_DOWNLOAD_LINK: "Es ist eine Aktualisierung verfügbar. Klicken Sie zum Herunterladen auf {0}", // Product name
    COPYRIGHT: "Copyright",
    IBM_LOGO: "IBM Logo",
    IBM_LICENSED: "Licensed Materials — Property of IBM © Copyright IBM Corp. 1997, 2019. All Rights Reserved. IBM und das IBM Logo sind Marken oder eingetragene Marken der International Business Machines Corporation in den USA und/oder anderen Ländern. Weitere Produkt- und Servicenamen können Marken von IBM oder anderen Unternehmen sein. Eine aktuelle Liste der IBM Marken finden Sie im Web unter {0}", // COPYRIGHT_URL
    COPYRIGHT_URL: "'Copyright and trademark information'.",
    CONTEXT_ROOT_NOT_FOUND: "Kontextstammverzeichnis nicht gefunden.",
    UPDATE_BANNER_CLOSE_BUTTON: "Banner schließen",
    UPDATE_BANNER_SECTION: "Bannerbereich aktualisieren",
    UPDATE_BANNER_SECTION_CONTENT: "Inhalt des Bannerbereichs aktualisieren",
    BUILT_ON: "Erstellt unter ",
    LINKS: "Links: "
};
